/*
 * Pidgin - Internet Messenger
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Pidgin is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PIDGIN_GLOBAL_HEADER_INSIDE) && !defined(PIDGIN_COMPILATION)
# error "only <pidgin.h> may be included directly"
#endif

#ifndef PIDGIN_BADGES_H
#define PIDGIN_BADGES_H

#include <gtk/gtk.h>

#include <adwaita.h>

#include <purple.h>

#include "pidginversion.h"

G_BEGIN_DECLS

/**
 * PidginBadges:
 *
 * A widget that is used to display a [class@Purple.Badges].
 *
 * Since: 3.0
 */

#define PIDGIN_TYPE_BADGES (pidgin_badges_get_type())

PIDGIN_AVAILABLE_IN_3_0
G_DECLARE_FINAL_TYPE(PidginBadges, pidgin_badges, PIDGIN, BADGES, AdwBin)

/**
 * pidgin_badges_new:
 * @badges: The badges to display.
 *
 * Displays badges.
 *
 * Returns: (transfer full): The new widget.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
GtkWidget *pidgin_badges_new(PurpleBadges *badges);

/**
 * pidgin_badges_get_badges:
 * @badges: The instance.
 *
 * Gets the badges that are being displayed.
 *
 * Returns: (transfer none) (nullable): The badges.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
PurpleBadges *pidgin_badges_get_badges(PidginBadges *badges);

/**
 * pidgin_badges_set_badges:
 * @pidgin_badges: The instance.
 * @purple_badges: (nullable) (transfer none): The new badges.
 *
 * Sets the badges to be displayed.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
void pidgin_badges_set_badges(PidginBadges *pidgin_badges, PurpleBadges *purple_badges);

G_END_DECLS

#endif /* PIDGIN_BADGES_H */
