/*
 * Pidgin - Internet Messenger
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Pidgin is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PIDGIN_GLOBAL_HEADER_INSIDE) && !defined(PIDGIN_COMPILATION)
# error "only <pidgin.h> may be included directly"
#endif

#ifndef PIDGIN_MESSAGE_H
#define PIDGIN_MESSAGE_H

#include <glib.h>

#include <gtk/gtk.h>

#include <purple.h>

#include "pidginversion.h"

G_BEGIN_DECLS

/**
 * PidginMessage:
 *
 * A widget for displaying a [class@Purple.Message].
 *
 * Since: 3.0
 */

#define PIDGIN_TYPE_MESSAGE (pidgin_message_get_type())

PIDGIN_AVAILABLE_IN_3_0
G_DECLARE_FINAL_TYPE(PidginMessage, pidgin_message, PIDGIN, MESSAGE, GtkBox)

/**
 * pidgin_message_new:
 * @message: (nullable): the message to display
 *
 * Creates a new widget that will display @message.
 *
 * Returns: (transfer full): The new instance.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
GtkWidget *pidgin_message_new(PurpleMessage *message);

/**
 * pidgin_message_get_message:
 *
 * Gets the [class@Purple.Message] that is being displayed.
 *
 * Returns: (transfer none) (nullable): The message.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
PurpleMessage *pidgin_message_get_message(PidginMessage *message);

/**
 * pidgin_message_set_message:
 * @purple_message: (nullable): the new message to display
 *
 * Sets the message to be displayed to @message.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
void pidgin_message_set_message(PidginMessage *pidgin_message, PurpleMessage *purple_message);

G_END_DECLS

#endif /* PIDGIN_MESSAGE_H */
